@@ -444,8 +444,6 @@ namespace Mono.WebServer
 			}
 		}
 
-
-		AsyncCallback accept_cb;
 		void RunServer ()
 		{
 			started = true;
@@ -537,7 +535,7 @@ namespace Mono.WebServer
 					ThreadPool.QueueUserWorkItem (new WaitCallback (worker.Run));
 				else
 					worker.Run (null);
-			} catch (Exception e) {
+			} catch (Exception) {
 				try {
 					if (accepted != null) {
 						try {
